@@ -367,15 +367,23 @@ void PdfParser::parse(Object *obj, GBool topLevel) {
     for (i = 0; i < obj->arrayGetLength(); ++i) {
       obj->arrayGet(i, &obj2);
       if (!obj2.isStream()) {
+#ifdef POPPLER_NEW_ERRORAPI
+	error(errInternal, -1, "Weird page contents");
+#else
 	error(-1, const_cast<char*>("Weird page contents"));
+#endif
 	obj2.free();
 	return;
       }
       obj2.free();
     }
   } else if (!obj->isStream()) {
-    error(-1, const_cast<char*>("Weird page contents"));
-    return;
+#ifdef POPPLER_NEW_ERRORAPI
+	error(errInternal, -1, "Weird page contents");
+#else
+	error(-1, const_cast<char*>("Weird page contents"));
+#endif
+    	return;
   }
   parser = new Parser(xref, new Lexer(xref, obj), gFalse);
   go(topLevel);
@@ -419,7 +427,11 @@ void PdfParser::go(GBool topLevel) {
 
     // too many arguments - something is wrong
     } else {
+#ifdef POPPLER_NEW_ERRORAPI
+      error(errSyntaxError, getPos(), "Too many args in content stream");
+#else
       error(getPos(), const_cast<char*>("Too many args in content stream"));
+#endif
       if (printCommands) {
 	printf("throwing away arg: ");
 	obj.print(stdout);
@@ -436,7 +448,11 @@ void PdfParser::go(GBool topLevel) {
 
   // args at end with no command
   if (numArgs > 0) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "Leftover args in content stream");
+#else
     error(getPos(), const_cast<char*>("Leftover args in content stream"));
+#endif
     if (printCommands) {
       printf("%d leftovers:", numArgs);
       for (i = 0; i < numArgs; ++i) {
@@ -502,7 +518,11 @@ void PdfParser::execOp(Object *cmd, Object args[], int numArgs) {
   name = cmd->getCmd();
   if (!(op = findOp(name))) {
     if (ignoreUndef == 0)
+#ifdef POPPLER_NEW_ERRORAPI
+      error(errSyntaxError, getPos(), "Unknown operator '{0:s}'", name);
+#else
       error(getPos(), const_cast<char*>("Unknown operator '%s'"), name);
+#endif
     return;
   }
 
@@ -510,26 +530,42 @@ void PdfParser::execOp(Object *cmd, Object args[], int numArgs) {
   argPtr = args;
   if (op->numArgs >= 0) {
     if (numArgs < op->numArgs) {
+#ifdef POPPLER_NEW_ERRORAPI
+      error(errSyntaxError, getPos(), "Too few ({0:d}) args to '{1:d}' operator", numArgs, name);
+#else
       error(getPos(), const_cast<char*>("Too few (%d) args to '%s' operator"), numArgs, name);
+#endif
       return;
     }
     if (numArgs > op->numArgs) {
 #if 0
+#ifdef POPPLER_NEW_ERRORAPI
+      error(errSyntaxError, getPos(), "Too many ({0:d}) args to '{1:s}' operator", numArgs, name);
+#else
       error(getPos(), "Too many (%d) args to '%s' operator", numArgs, name);
+#endif
 #endif
       argPtr += numArgs - op->numArgs;
       numArgs = op->numArgs;
     }
   } else {
     if (numArgs > -op->numArgs) {
+#ifdef POPPLER_NEW_ERRORAPI
+      error(errSyntaxError, getPos(), "Too many ({0:d}) args to '{1:s}' operator",
+#else
       error(getPos(), const_cast<char*>("Too many (%d) args to '%s' operator"),
+#endif
 	    numArgs, name);
       return;
     }
   }
   for (i = 0; i < numArgs; ++i) {
     if (!checkArg(&argPtr[i], op->tchk[i])) {
+#ifdef POPPLER_NEW_ERRORAPI
+      error(errSyntaxError, getPos(), "Arg #{0:d} to '{1:s}' operator is wrong type ({2:s})",
+#else
       error(getPos(), const_cast<char*>("Arg #%d to '%s' operator is wrong type (%s)"),
+#endif
 	    i, name, argPtr[i].getTypeName());
       return;
     }
@@ -690,7 +726,11 @@ void PdfParser::opSetExtGState(Object args[], int numArgs) {
     return;
   }
   if (!obj1.isDict()) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "ExtGState '{0:s}' is wrong type"), args[0].getName();
+#else
     error(getPos(), const_cast<char*>("ExtGState '%s' is wrong type"), args[0].getName());
+#endif
     obj1.free();
     return;
   }
@@ -705,7 +745,11 @@ void PdfParser::opSetExtGState(Object args[], int numArgs) {
     if (state->parseBlendMode(&obj2, &mode)) {
       state->setBlendMode(mode);
     } else {
+#ifdef POPPLER_NEW_ERRORAPI
+      error(errSyntaxError, getPos(), "Invalid blend mode in ExtGState");
+#else
       error(getPos(), const_cast<char*>("Invalid blend mode in ExtGState"));
+#endif
     }
   }
   obj2.free();
@@ -764,7 +808,11 @@ void PdfParser::opSetExtGState(Object args[], int numArgs) {
       state->setTransfer(funcs);
     }
   } else if (!obj2.isNull()) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "Invalid transfer function in ExtGState");
+#else
     error(getPos(), const_cast<char*>("Invalid transfer function in ExtGState"));
+#endif
   }
   obj2.free();
 
@@ -784,8 +832,11 @@ void PdfParser::opSetExtGState(Object args[], int numArgs) {
 	funcs[0] = Function::parse(&obj3);
 	if (funcs[0]->getInputSize() != 1 ||
 	    funcs[0]->getOutputSize() != 1) {
-	  error(getPos(),
-		const_cast<char*>("Invalid transfer function in soft mask in ExtGState"));
+#ifdef POPPLER_NEW_ERRORAPI
+	  error(errSyntaxError, getPos(), "Invalid transfer function in soft mask in ExtGState");
+#else
+	  error(getPos(), const_cast<char*>("Invalid transfer function in soft mask in ExtGState"));
+#endif
 	  delete funcs[0];
 	  funcs[0] = NULL;
 	}
@@ -809,7 +860,13 @@ void PdfParser::opSetExtGState(Object args[], int numArgs) {
 	  blendingColorSpace = NULL;
 	  isolated = knockout = gFalse;
 	  if (!obj4.dictLookup(const_cast<char*>("CS"), &obj5)->isNull()) {
+#if defined(POPPLER_EVEN_NEWER_COLOR_SPACE_API)
+	    blendingColorSpace = GfxColorSpace::parse(&obj5, NULL, NULL);
+#elif defined(POPPLER_NEW_COLOR_SPACE_API) || defined(POPPLER_NEW_ERRORAPI)
+	    blendingColorSpace = GfxColorSpace::parse(&obj5, NULL);
+#else
 	    blendingColorSpace = GfxColorSpace::parse(&obj5);
+#endif
 	  }
 	  obj5.free();
 	  if (obj4.dictLookup(const_cast<char*>("I"), &obj5)->isBool()) {
@@ -836,15 +893,27 @@ void PdfParser::opSetExtGState(Object args[], int numArgs) {
 	    delete funcs[0];
 	  }
 	} else {
+#ifdef POPPLER_NEW_ERRORAPI
+	  error(errSyntaxError, getPos(), "Invalid soft mask in ExtGState - missing group");
+#else
 	  error(getPos(), const_cast<char*>("Invalid soft mask in ExtGState - missing group"));
+#endif
 	}
 	obj4.free();
       } else {
+#ifdef POPPLER_NEW_ERRORAPI
+	error(errSyntaxError, getPos(), "Invalid soft mask in ExtGState - missing group");
+#else
 	error(getPos(), const_cast<char*>("Invalid soft mask in ExtGState - missing group"));
+#endif
       }
       obj3.free();
     } else if (!obj2.isNull()) {
+#ifdef POPPLER_NEW_ERRORAPI
+      error(errSyntaxError, getPos(), "Invalid soft mask in ExtGState");
+#else
       error(getPos(), const_cast<char*>("Invalid soft mask in ExtGState"));
+#endif
     }
   }
   obj2.free();
@@ -872,7 +941,11 @@ void PdfParser::doSoftMask(Object *str, GBool alpha,
   // check form type
   dict->lookup(const_cast<char*>("FormType"), &obj1);
   if (!(obj1.isNull() || (obj1.isInt() && obj1.getInt() == 1))) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "Unknown form type");
+#else
     error(getPos(), const_cast<char*>("Unknown form type"));
+#endif
   }
   obj1.free();
 
@@ -880,7 +953,11 @@ void PdfParser::doSoftMask(Object *str, GBool alpha,
   dict->lookup(const_cast<char*>("BBox"), &obj1);
   if (!obj1.isArray()) {
     obj1.free();
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "Bad form bounding box");
+#else
     error(getPos(), const_cast<char*>("Bad form bounding box"));
+#endif
     return;
   }
   for (i = 0; i < 4; ++i) {
@@ -1008,11 +1085,25 @@ void PdfParser::opSetFillColorSpace(Object args[], int numArgs) {
 
   state->setFillPattern(NULL);
   res->lookupColorSpace(args[0].getName(), &obj);
+#if defined(POPPLER_EVEN_NEWER_COLOR_SPACE_API)
+  if (obj.isNull()) {
+    colorSpace = GfxColorSpace::parse(&args[0], NULL, NULL);
+  } else {
+    colorSpace = GfxColorSpace::parse(&obj, NULL, NULL);
+  }
+#elif defined(POPPLER_NEW_COLOR_SPACE_API) || defined(POPPLER_NEW_ERRORAPI)
+  if (obj.isNull()) {
+    colorSpace = GfxColorSpace::parse(&args[0], NULL);
+  } else {
+    colorSpace = GfxColorSpace::parse(&obj, NULL);
+  }
+#else
   if (obj.isNull()) {
     colorSpace = GfxColorSpace::parse(&args[0]);
   } else {
     colorSpace = GfxColorSpace::parse(&obj);
   }
+#endif
   obj.free();
   if (colorSpace) {
     state->setFillColorSpace(colorSpace);
@@ -1020,7 +1111,11 @@ void PdfParser::opSetFillColorSpace(Object args[], int numArgs) {
     state->setFillColor(&color);
     builder->updateStyle(state);
   } else {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "Bad color space (fill)");
+#else
     error(getPos(), const_cast<char*>("Bad color space (fill)"));
+#endif
   }
 }
 
@@ -1031,11 +1126,25 @@ void PdfParser::opSetStrokeColorSpace(Object args[], int numArgs) {
 
   state->setStrokePattern(NULL);
   res->lookupColorSpace(args[0].getName(), &obj);
+#if defined(POPPLER_EVEN_NEWER_COLOR_SPACE_API)
+  if (obj.isNull()) {
+    colorSpace = GfxColorSpace::parse(&args[0], NULL, NULL);
+  } else {
+    colorSpace = GfxColorSpace::parse(&obj, NULL, NULL);
+  }
+#elif defined(POPPLER_NEW_COLOR_SPACE_API) || defined(POPPLER_NEW_ERRORAPI)
+  if (obj.isNull()) {
+    colorSpace = GfxColorSpace::parse(&args[0], NULL);
+  } else {
+    colorSpace = GfxColorSpace::parse(&obj, NULL);
+  }
+#else
   if (obj.isNull()) {
     colorSpace = GfxColorSpace::parse(&args[0]);
   } else {
     colorSpace = GfxColorSpace::parse(&obj);
   }
+#endif
   obj.free();
   if (colorSpace) {
     state->setStrokeColorSpace(colorSpace);
@@ -1043,7 +1152,11 @@ void PdfParser::opSetStrokeColorSpace(Object args[], int numArgs) {
     state->setStrokeColor(&color);
     builder->updateStyle(state);
   } else {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "Bad color space (stroke)");
+#else
     error(getPos(), const_cast<char*>("Bad color space (stroke)"));
+#endif
   }
 }
 
@@ -1052,7 +1165,11 @@ void PdfParser::opSetFillColor(Object args[], int numArgs) {
   int i;
 
   if (numArgs != state->getFillColorSpace()->getNComps()) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "Incorrect number of arguments in 'sc' command");
+#else
     error(getPos(), const_cast<char*>("Incorrect number of arguments in 'sc' command"));
+#endif
     return;
   }
   state->setFillPattern(NULL);
@@ -1068,7 +1185,11 @@ void PdfParser::opSetStrokeColor(Object args[], int numArgs) {
   int i;
 
   if (numArgs != state->getStrokeColorSpace()->getNComps()) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "Incorrect number of arguments in 'SC' command");
+#else
     error(getPos(), const_cast<char*>("Incorrect number of arguments in 'SC' command"));
+#endif
     return;
   }
   state->setStrokePattern(NULL);
@@ -1089,7 +1210,11 @@ void PdfParser::opSetFillColorN(Object args[], int numArgs) {
       if (!((GfxPatternColorSpace *)state->getFillColorSpace())->getUnder() ||
 	  numArgs - 1 != ((GfxPatternColorSpace *)state->getFillColorSpace())
 	                     ->getUnder()->getNComps()) {
+#ifdef POPPLER_NEW_ERRORAPI
+	error(errSyntaxError, getPos(), "Incorrect number of arguments in 'scn' command");
+#else
 	error(getPos(), const_cast<char*>("Incorrect number of arguments in 'scn' command"));
+#endif
 	return;
       }
       for (i = 0; i < numArgs - 1 && i < gfxColorMaxComps; ++i) {
@@ -1100,15 +1225,33 @@ void PdfParser::opSetFillColorN(Object args[], int numArgs) {
       state->setFillColor(&color);
       builder->updateStyle(state);
     }
+#if defined(POPPLER_EVEN_NEWER_COLOR_SPACE_API)
+    if (args[numArgs-1].isName() &&
+	(pattern = res->lookupPattern(args[numArgs-1].getName(), NULL, NULL))) {
+      state->setFillPattern(pattern);
+      builder->updateStyle(state);
+    }
+#elif defined(POPPLER_NEW_COLOR_SPACE_API) || defined(POPPLER_NEW_ERRORAPI)
+    if (args[numArgs-1].isName() &&
+	(pattern = res->lookupPattern(args[numArgs-1].getName(), NULL))) {
+      state->setFillPattern(pattern);
+      builder->updateStyle(state);
+    }
+#else
     if (args[numArgs-1].isName() &&
 	(pattern = res->lookupPattern(args[numArgs-1].getName()))) {
       state->setFillPattern(pattern);
       builder->updateStyle(state);
     }
+#endif
 
   } else {
     if (numArgs != state->getFillColorSpace()->getNComps()) {
+#ifdef POPPLER_NEW_ERRORAPI
+      error(errSyntaxError, getPos(), "Incorrect number of arguments in 'scn' command");
+#else
       error(getPos(), const_cast<char*>("Incorrect number of arguments in 'scn' command"));
+#endif
       return;
     }
     state->setFillPattern(NULL);
@@ -1133,7 +1276,11 @@ void PdfParser::opSetStrokeColorN(Object args[], int numArgs) {
 	       ->getUnder() ||
 	  numArgs - 1 != ((GfxPatternColorSpace *)state->getStrokeColorSpace())
 	                     ->getUnder()->getNComps()) {
+#ifdef POPPLER_NEW_ERRORAPI
+	error(errSyntaxError, getPos(), "Incorrect number of arguments in 'SCN' command");
+#else
 	error(getPos(), const_cast<char*>("Incorrect number of arguments in 'SCN' command"));
+#endif
 	return;
       }
       for (i = 0; i < numArgs - 1 && i < gfxColorMaxComps; ++i) {
@@ -1144,15 +1291,33 @@ void PdfParser::opSetStrokeColorN(Object args[], int numArgs) {
       state->setStrokeColor(&color);
       builder->updateStyle(state);
     }
+#if defined(POPPLER_EVEN_NEWER_COLOR_SPACE_API)
+    if (args[numArgs-1].isName() &&
+	(pattern = res->lookupPattern(args[numArgs-1].getName(), NULL, NULL))) {
+      state->setStrokePattern(pattern);
+      builder->updateStyle(state);
+    }
+#elif defined(POPPLER_NEW_COLOR_SPACE_API) || defined(POPPLER_NEW_ERRORAPI)
+    if (args[numArgs-1].isName() &&
+	(pattern = res->lookupPattern(args[numArgs-1].getName(), NULL))) {
+      state->setStrokePattern(pattern);
+      builder->updateStyle(state);
+    }
+#else
     if (args[numArgs-1].isName() &&
 	(pattern = res->lookupPattern(args[numArgs-1].getName()))) {
       state->setStrokePattern(pattern);
       builder->updateStyle(state);
     }
+#endif
 
   } else {
     if (numArgs != state->getStrokeColorSpace()->getNComps()) {
+#ifdef POPPLER_NEW_ERRORAPI
+      error(errSyntaxError, getPos(), "Incorrect number of arguments in 'SCN' command");
+#else
       error(getPos(), const_cast<char*>("Incorrect number of arguments in 'SCN' command"));
+#endif
       return;
     }
     state->setStrokePattern(NULL);
@@ -1176,7 +1341,11 @@ void PdfParser::opMoveTo(Object args[], int numArgs) {
 
 void PdfParser::opLineTo(Object args[], int numArgs) {
   if (!state->isCurPt()) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "No current point in lineto");
+#else
     error(getPos(), const_cast<char*>("No current point in lineto"));
+#endif
     return;
   }
   state->lineTo(args[0].getNum(), args[1].getNum());
@@ -1186,7 +1355,11 @@ void PdfParser::opCurveTo(Object args[], int numArgs) {
   double x1, y1, x2, y2, x3, y3;
 
   if (!state->isCurPt()) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "No current point in curveto");
+#else
     error(getPos(), const_cast<char*>("No current point in curveto"));
+#endif
     return;
   }
   x1 = args[0].getNum();
@@ -1202,7 +1375,11 @@ void PdfParser::opCurveTo1(Object args[], int numArgs) {
   double x1, y1, x2, y2, x3, y3;
 
   if (!state->isCurPt()) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "No current point in curveto1");
+#else
     error(getPos(), const_cast<char*>("No current point in curveto1"));
+#endif
     return;
   }
   x1 = state->getCurX();
@@ -1218,7 +1395,11 @@ void PdfParser::opCurveTo2(Object args[], int numArgs) {
   double x1, y1, x2, y2, x3, y3;
 
   if (!state->isCurPt()) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "No current point in curveto2");
+#else
     error(getPos(), const_cast<char*>("No current point in curveto2"));
+#endif
     return;
   }
   x1 = args[0].getNum();
@@ -1246,7 +1427,11 @@ void PdfParser::opRectangle(Object args[], int numArgs) {
 
 void PdfParser::opClosePath(Object args[], int numArgs) {
   if (!state->isCurPt()) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "No current point in closepath");
+#else
     error(getPos(), const_cast<char*>("No current point in closepath"));
+#endif
     return;
   }
   state->closePath();
@@ -1404,7 +1589,11 @@ void PdfParser::doPatternFillFallback(GBool eoFill) {
     doShadingPatternFillFallback((GfxShadingPattern *)pattern, gFalse, eoFill);
     break;
   default:
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errUnimplemented, getPos(), "Unimplemented pattern type (%d) in fill",
+#else
     error(getPos(), const_cast<char*>("Unimplemented pattern type (%d) in fill"),
+#endif
 	  pattern->getType());
     break;
   }
@@ -1423,7 +1612,11 @@ void PdfParser::doPatternStrokeFallback() {
     doShadingPatternFillFallback((GfxShadingPattern *)pattern, gTrue, gFalse);
     break;
   default:
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errUnimplemented, getPos(), "Unimplemented pattern type ({0:d}) in stroke",
+#else
     error(getPos(), const_cast<char*>("Unimplemented pattern type (%d) in stroke"),
+#endif
 	  pattern->getType());
     break;
   }
@@ -1543,9 +1736,19 @@ void PdfParser::opShFill(Object args[], int numArgs) {
   double *matrix = NULL;
   GBool savedState = gFalse;
 
+#if defined(POPPLER_EVEN_NEWER_COLOR_SPACE_API)
+  if (!(shading = res->lookupShading(args[0].getName(), NULL, NULL))) {
+    return;
+  }
+#elif defined(POPPLER_NEW_COLOR_SPACE_API) || defined(POPPLER_NEW_ERRORAPI)
+  if (!(shading = res->lookupShading(args[0].getName(), NULL))) {
+    return;
+  }
+#else
   if (!(shading = res->lookupShading(args[0].getName()))) {
     return;
   }
+#endif
 
   // save current graphics state
   if (shading->getType() != 2 && shading->getType() != 3) {
@@ -1832,6 +2035,9 @@ void PdfParser::doPatchMeshShFill(GfxPatchMeshShading *shading) {
 
 void PdfParser::fillPatch(GfxPatch *patch, int nComps, int depth) {
   GfxPatch patch00, patch01, patch10, patch11;
+#ifdef POPPLER_NEW_GFXPATCH
+  GfxColor color;
+#endif
   double xx[4][8], yy[4][8];
   double xxm, yym;
   double patchColorDelta = colorDeltas[pdfPatchMeshShading-1];
@@ -1848,9 +2054,16 @@ void PdfParser::fillPatch(GfxPatch *patch, int nComps, int depth) {
 	  > patchColorDelta) {
       break;
     }
+#ifdef POPPLER_NEW_GFXPATCH
+    color.c[i] = GfxColorComp(patch->color[0][0].c[i]);
+#endif
   }
   if (i == nComps || depth == maxDepths[pdfPatchMeshShading-1]) {
+#ifdef POPPLER_NEW_GFXPATCH
+    state->setFillColor(&color);
+#else
     state->setFillColor(&patch->color[0][0]);
+#endif
     state->moveTo(patch->x[0][0], patch->y[0][0]);
     state->curveTo(patch->x[0][1], patch->y[0][1],
 		   patch->x[0][2], patch->y[0][2],
@@ -2104,7 +2317,11 @@ void PdfParser::opTextNextLine(Object args[], int numArgs) {
 
 void PdfParser::opShowText(Object args[], int numArgs) {
   if (!state->getFont()) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "No font in show");
+#else
     error(getPos(), const_cast<char*>("No font in show"));
+#endif
     return;
   }
   if (fontChanged) {
@@ -2118,7 +2335,11 @@ void PdfParser::opMoveShowText(Object args[], int numArgs) {
   double tx, ty;
 
   if (!state->getFont()) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "No font in move/show");
+#else
     error(getPos(), const_cast<char*>("No font in move/show"));
+#endif
     return;
   }
   if (fontChanged) {
@@ -2136,7 +2357,11 @@ void PdfParser::opMoveSetShowText(Object args[], int numArgs) {
   double tx, ty;
 
   if (!state->getFont()) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "No font in move/set/show");
+#else
     error(getPos(), const_cast<char*>("No font in move/set/show"));
+#endif
     return;
   }
   if (fontChanged) {
@@ -2159,7 +2384,11 @@ void PdfParser::opShowSpaceText(Object args[], int numArgs) {
   int i;
 
   if (!state->getFont()) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "No font in show/space");
+#else
     error(getPos(), const_cast<char*>("No font in show/space"));
+#endif
     return;
   }
   if (fontChanged) {
@@ -2184,7 +2413,11 @@ void PdfParser::opShowSpaceText(Object args[], int numArgs) {
     } else if (obj.isString()) {
       doShowText(obj.getString());
     } else {
+#ifdef POPPLER_NEW_ERRORAPI
+      error(errSyntaxError, getPos(), "Element of show/space array must be number or string");
+#else
       error(getPos(), const_cast<char*>("Element of show/space array must be number or string"));
+#endif
     }
     obj.free();
   }
@@ -2282,7 +2515,11 @@ void PdfParser::doShowText(GooString *s) {
 	if (charProc.isStream()) {
 	  //parse(&charProc, gFalse); // TODO: parse into SVG font
 	} else {
+#ifdef POPPLER_NEW_ERRORAPI
+	  error(errSyntaxError, getPos(), "Missing or bad Type3 CharProc entry");
+#else
 	  error(getPos(), const_cast<char*>("Missing or bad Type3 CharProc entry"));
+#endif
 	}
 	//out->endType3Char(state);
 	if (resDict) {
@@ -2358,7 +2595,11 @@ void PdfParser::opXObject(Object args[], int numArgs) {
     return;
   }
   if (!obj1.isStream()) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "XObject '{0:s}' is wrong type", name);
+#else
     error(getPos(), const_cast<char*>("XObject '%s' is wrong type"), name);
+#endif
     obj1.free();
     return;
   }
@@ -2374,9 +2615,17 @@ void PdfParser::opXObject(Object args[], int numArgs) {
 /*    out->psXObject(obj1.getStream(),
     		   obj3.isStream() ? obj3.getStream() : (Stream *)NULL);*/
   } else if (obj2.isName()) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "Unknown XObject subtype '{0:s}'", obj2.getName());
+#else
     error(getPos(), const_cast<char*>("Unknown XObject subtype '%s'"), obj2.getName());
+#endif
   } else {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "XObject subtype is missing or wrong type");
+#else
     error(getPos(), const_cast<char*>("XObject subtype is missing or wrong type"));
+#endif
   }
   obj2.free();
   obj1.free();
@@ -2507,7 +2756,13 @@ void PdfParser::doImage(Object *ref, Stream *str, GBool inlineImg) {
       }
     }
     if (!obj1.isNull()) {
+#if defined(POPPLER_EVEN_NEWER_COLOR_SPACE_API)
+            colorSpace = GfxColorSpace::parse(&obj1, NULL, NULL);
+#elif defined(POPPLER_NEW_COLOR_SPACE_API) || defined(POPPLER_NEW_ERRORAPI)
+      colorSpace = GfxColorSpace::parse(&obj1, NULL);
+#else
       colorSpace = GfxColorSpace::parse(&obj1);
+#endif
     } else if (csMode == streamCSDeviceGray) {
       colorSpace = new GfxDeviceGrayColorSpace();
     } else if (csMode == streamCSDeviceRGB) {
@@ -2592,7 +2847,13 @@ void PdfParser::doImage(Object *ref, Stream *str, GBool inlineImg) {
 	  obj2.free();
 	}
       }
+#if defined(POPPLER_EVEN_NEWER_COLOR_SPACE_API)
+            GfxColorSpace *maskColorSpace = GfxColorSpace::parse(&obj1, NULL, NULL);
+#elif defined(POPPLER_NEW_COLOR_SPACE_API) || defined(POPPLER_NEW_ERRORAPI)
+      maskColorSpace = GfxColorSpace::parse(&obj1, NULL);
+#else
       maskColorSpace = GfxColorSpace::parse(&obj1);
+#endif
       obj1.free();
       if (!maskColorSpace || maskColorSpace->getMode() != csDeviceGray) {
 	goto err1;
@@ -2698,7 +2959,11 @@ void PdfParser::doImage(Object *ref, Stream *str, GBool inlineImg) {
  err2:
   obj1.free();
  err1:
+#ifdef POPPLER_NEW_ERRORAPI
+  error(errSyntaxError, getPos(), "Bad image parameters");
+#else
   error(getPos(), const_cast<char*>("Bad image parameters"));
+#endif
 }
 
 void PdfParser::doForm(Object *str) {
@@ -2723,7 +2988,11 @@ void PdfParser::doForm(Object *str) {
   // check form type
   dict->lookup(const_cast<char*>("FormType"), &obj1);
   if (!(obj1.isNull() || (obj1.isInt() && obj1.getInt() == 1))) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "Unknown form type");
+#else
     error(getPos(), const_cast<char*>("Unknown form type"));
+#endif
   }
   obj1.free();
 
@@ -2731,7 +3000,11 @@ void PdfParser::doForm(Object *str) {
   dict->lookup(const_cast<char*>("BBox"), &bboxObj);
   if (!bboxObj.isArray()) {
     bboxObj.free();
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "Bad form bounding box");
+#else
     error(getPos(), const_cast<char*>("Bad form bounding box"));
+#endif
     return;
   }
   for (i = 0; i < 4; ++i) {
@@ -2767,7 +3040,13 @@ void PdfParser::doForm(Object *str) {
     if (obj1.dictLookup(const_cast<char*>("S"), &obj2)->isName(const_cast<char*>("Transparency"))) {
       transpGroup = gTrue;
       if (!obj1.dictLookup(const_cast<char*>("CS"), &obj3)->isNull()) {
+#if defined(POPPLER_EVEN_NEWER_COLOR_SPACE_API)
+	blendingColorSpace = GfxColorSpace::parse(&obj3, NULL, NULL);
+#elif defined(POPPLER_NEW_COLOR_SPACE_API) || defined(POPPLER_NEW_ERRORAPI)
+	blendingColorSpace = GfxColorSpace::parse(&obj3, NULL);
+#else
 	blendingColorSpace = GfxColorSpace::parse(&obj3);
+#endif
       }
       obj3.free();
       if (obj1.dictLookup(const_cast<char*>("I"), &obj3)->isBool()) {
@@ -2926,7 +3205,11 @@ Stream *PdfParser::buildImageStream() {
   parser->getObj(&obj);
   while (!obj.isCmd(const_cast<char*>("ID")) && !obj.isEOF()) {
     if (!obj.isName()) {
+#ifdef POPPLER_NEW_ERRORAPI
+      error(errSyntaxError, getPos(), "Inline image dictionary key must be a name object");
+#else
       error(getPos(), const_cast<char*>("Inline image dictionary key must be a name object"));
+#endif
       obj.free();
     } else {
       key = copyString(obj.getName());
@@ -2941,7 +3224,11 @@ Stream *PdfParser::buildImageStream() {
     parser->getObj(&obj);
   }
   if (obj.isEOF()) {
+#ifdef POPPLER_NEW_ERRORAPI
+    error(errSyntaxError, getPos(), "End of file in inline image");
+#else
     error(getPos(), const_cast<char*>("End of file in inline image"));
+#endif
     obj.free();
     dict.free();
     return NULL;
@@ -2956,11 +3243,19 @@ Stream *PdfParser::buildImageStream() {
 }
 
 void PdfParser::opImageData(Object args[], int numArgs) {
+#ifdef POPPLER_NEW_ERRORAPI
+  error(errInternal, getPos(), "Internal: got 'ID' operator");
+#else
   error(getPos(), const_cast<char*>("Internal: got 'ID' operator"));
+#endif
 }
 
 void PdfParser::opEndImage(Object args[], int numArgs) {
+#ifdef POPPLER_NEW_ERRORAPI
+  error(errInternal, getPos(), "Internal: got 'EI' operator");
+#else
   error(getPos(), const_cast<char*>("Internal: got 'EI' operator"));
+#endif
 }
 
 //------------------------------------------------------------------------
