@@ -18,7 +18,6 @@
 #include <interface.h>
 #include <libnr/nr-pixops.h>
 #include <glib.h>
-#include <glib/gmessages.h>
 #include <png.h>
 #include "png-write.h"
 #include <display/nr-arena-item.h>
@@ -26,6 +25,7 @@
 #include <document.h>
 #include <sp-item.h>
 #include <sp-root.h>
+#include <sp-use.h>
 #include <sp-defs.h>
 #include "unit-constants.h"
 
@@ -47,6 +47,7 @@ hide_other_items_recursively(SPObject *o, GSList *list, unsigned dkey)
          && !SP_IS_DEFS(o)
          && !SP_IS_ROOT(o)
          && !SP_IS_GROUP(o)
+         && !SP_IS_USE(o)
          && !g_slist_find(list, o) )
     {
         sp_item_invoke_hide(SP_ITEM(o), dkey);
@@ -84,7 +85,7 @@ sp_export_jpg_file(SPDocument *doc, gchar const *filename,
      g_snprintf(c, 32, "%f", quality);
      gboolean saved = gdk_pixbuf_save (pixbuf, filename, "jpeg", NULL, "quality", c, NULL);
      g_free(c);
-     gdk_pixbuf_unref (pixbuf);
+     g_object_unref(G_OBJECT(pixbuf));
      if (saved) return true;
      else return false;
 }
